{ nix-flatpak, lib, pkgs, ... }:
{
  nixpkgs.config.allowUnfree = true;
  home = {
    packages = with pkgs; [
      gnupg
      eza
      just
      fd
      fzf
      bat
      jq
      yt-dlp
      htop
      ripgrep
      erdtree
      age
      figlet
      ffmpeg
      rlwrap

      mesa      
      usbutils
      pciutils
      util-linux
      coreutils
      libgcc
      raylib
      SDL2
      protonplus

      ruby
      janet
      jpm
      python3
      sbcl
      nodejs_18
      platformio-core

      borgmatic
      kanata-with-cmd
      wezterm 
      emacs
      starship
      lazygit
      nnn
      isync
      msmtp
      mu
      jetbrains-mono

      fish
      fishPlugins.foreign-env
      fishPlugins.z
      fishPlugins.fzf
      #fishPlugins.fifc
      fishPlugins.bass
      fishPlugins.autopair

      via
      bitwarden-cli
      bitwarden-desktop
      tailscale
      protonplus
      gnomeExtensions.just-perfection
      gnomeExtensions.dash-to-dock
      gnomeExtensions.pano
      gnome-software
      gnome-tweaks
      colloid-gtk-theme
      colloid-icon-theme
      #turtle
      papers
      newsflash
      #helvum
      
      librewolf
      ungoogled-chromium
      ulauncher
      obsidian
      vlc
      polychromatic
      discord
      slack
      signal-desktop
      libreoffice
      plexamp
      audacity
      supercollider-with-plugins
      bitwig-studio
      blender
      davinci-resolve-studio
      steam
      zotero_7
    ];

    username = "emenel";
    homeDirectory = "/home/emenel";

    sessionPath = [ "/home/emenel/.config/emacs/bin" ];

    stateVersion = "24.05";
  };

  programs = {
    home-manager.enable = true;
    direnv = {
      enable = true;
      #enableFishIntegration = true; # see note on other shells below
      nix-direnv.enable = true;
    };
    fish = {
      enable = true;
      #vendor = {
      #  completions.enable = true;
      #  config.enable = true;
      #  functions.enable = true;
      #};
    };
    starship = {
      enable = true;
      enableFishIntegration = true;
    };
    mu.enable = true;
    mbsync.enable = true;
    msmtp.enable = true;
  };

  services = {
    flatpak.enable = true;
    #tailscale.enable = true;

    #mbsync.configFile = ../dotfiles/dot_config/isyncrc;
  };

  xdg.systemDirs.data = [
    "/home/emenel/.local/share/applications/wine/Programs"
    "/home/emenel/.local/share/applications"
    "/var/lib/flatpak/exports/share"
    "/home/emenel/.local/share/flatpak/exports/share"
    "/home/emenel/.nix-profile/share/applications"
  ];

  services.flatpak.packages = [
    "io.github.zen_browser.zen"
    "com.github.johnfactotum.QuickLookup"
  ];

  xdg.configFile."kmonad".source = ../dotfiles/dot_config/kmonad;

  xdg.configFile."starship.toml".source = ../dotfiles/dot_config/starship.toml;
  xdg.configFile."wezterm".source = ../dotfiles/dot_config/wezterm;

  xdg.configFile."fish/functions" = {
    source = ../dotfiles/dot_config/fish/functions;
    recursive = true;
  };

  xdg.configFile."emacs".enable = false;
  home.file.".msmtprc".source = ../dotfiles/dot_msmtprc;
  home.file.".mbsyncrc".source = ../dotfiles/dot_mbsyncrc;
}
